@@ -1,5 +1,4 @@
-from sentinel.path import Path
-from sentinel.files import File
+from . import Path, File
 
 __all__ = ['Snapshot']
 
